CREATE TABLE "@wa_article" (
  "article_id" INTEGER AUTOINCREMENT NOT NULL,
  "category_id" INTEGER(10) NOT NULL,
  "status" INTEGER(1) DEFAULT 0,
  "title" TEXT NOT NULL,
  "content_key" TEXT(255),
  "member_id" INTEGER(11) DEFAULT 0,
  "author" TEXT(255),
  "copyright" TEXT(255),
  "thumbs" TEXT(200),
  "hits" INTEGER(10) DEFAULT 0,
  "robots" TEXT(255),
  "files" TEXT,
  "timeadd" INTEGER(10) DEFAULT 0,
  PRIMARY KEY ("article_id")
);

CREATE INDEX "category_id" ON "@wa_article" ("category_id" ASC);
CREATE INDEX "member_id" ON "@wa_article" ("member_id" ASC);
CREATE INDEX "content_key" ON "@wa_article" ("content_key" ASC);

CREATE TABLE "@wa_article_lang" (
  "article_id" INTEGER(11) NOT NULL,
  "lang" TEXT(30) NOT NULL,
  "title" TEXT(255) NOT NULL,
  "content" TEXT NOT NULL,
  "translator" TEXT(150),
  "meta_keywords" TEXT(255),
  "meta_description" TEXT(255),
  "commentid" INTEGER(15) DEFAULT 0,
  "options" TEXT,
  "timeedit" INTEGER(10) DEFAULT 0,
  PRIMARY KEY ("article_id","lang")
);

CREATE TABLE "@wa_category" (
  "category_id" INTEGER AUTOINCREMENT NOT NULL,
  "parentid" INTEGER(10) DEFAULT 0,
  "status" INTEGER(1) DEFAULT 1,
  "category" TEXT NOT NULL,
  "category_key" TEXT(255),
  "ordernum" INTEGER(8) DEFAULT '50',
  "category_cache" INTEGER(8) DEFAULT -1,
  "content_cache" INTEGER(8) DEFAULT -1,
  "redirect" TEXT(255),
  PRIMARY KEY ("category_id")
);

CREATE INDEX "parentid" ON "@wa_category" ("parentid" ASC);
CREATE INDEX "ordernum" ON "@wa_category" ("ordernum" ASC);
CREATE INDEX "category_key" ON "@wa_category" ("category_key" ASC);

CREATE TABLE "@wa_category_lang" (
  "category_id" INTEGER(10) NOT NULL,
  "lang" TEXT(30) NOT NULL,
  "category" TEXT(150) NOT NULL,
  "category_tpl" TEXT(255),
  "content_tpl" TEXT(255),
  "meta_keywords" TEXT(255),
  "meta_description" TEXT(255),
  "options" TEXT,
  PRIMARY KEY ("category_id","lang")
);

CREATE TABLE "@wa_comment" (
  "comment_id" INTEGER AUTOINCREMENT NOT NULL,
  "commentid" INTEGER(15) NOT NULL,
  "member_id" INTEGER(11) DEFAULT 0,
  "username" TEXT(50),
  "comment" TEXT NOT NULL,
  "timeadd" INTEGER(10) DEFAULT 0,
  PRIMARY KEY ("comment_id")
);

CREATE INDEX "commentid" ON "@wa_comment" ("commentid" ASC);

CREATE TABLE "@wa_cron" (
  "cron" TEXT(80) NOT NULL,
  "title" TEXT(80) NOT NULL,
  "status" INTEGER(1) DEFAULT 1,
  "intervals" INTEGER(8) DEFAULT 0,
  "next_run" INTEGER(10) DEFAULT 0,
  "runs" INTEGER(10) DEFAULT 0,
  "description" TEXT,
  PRIMARY KEY ("cron")
);

CREATE INDEX "status" ON "@wa_cron" ("status" ASC);

CREATE TABLE "@wa_currency" (
  "currency" TEXT(3) NOT NULL,
  "symbol" TEXT(10),
  "unit" TEXT(10) ,
  "rate" REAL(10,6) NOT NULL,
  "decimals" INTEGER(1) DEFAULT 2,
  PRIMARY KEY ("currency")
);

CREATE TABLE "@wa_member" (
  "member_id" INTEGER AUTOINCREMENT NOT NULL,
  "member_gid" INTEGER(4) DEFAULT 0,
  "username" TEXT(50) NOT NULL,
  "password" TEXT(32) NOT NULL,
  "status" INTEGER(1) DEFAULT 0,
  "email" TEXT(200) NOT NULL,
  "balance" REAL(15,2) DEFAULT '0.00',
  "frozen" REAL(15,2) DEFAULT '0.00',
  "points" INTEGER(15) DEFAULT 0,
  "usedsize" INTEGER(10) DEFAULT 0,
  "memship" TEXT(50),
  "ipadd" TEXT(39),
  "timeadd" INTEGER(10) DEFAULT 0,
  "ipprev" TEXT(39),
  "timeprev" INTEGER(10) DEFAULT 0,
  "iplast" TEXT(39),
  "timelast" INTEGER(10) DEFAULT 0,
  PRIMARY KEY ("member_id")
);

CREATE UNIQUE INDEX "username" ON "@wa_member" ("username" ASC);

CREATE TABLE "@wa_member_default" (
  "member_id" INTEGER(11) NOT NULL,
  "firstname" TEXT(50),
  "lastname" TEXT(50),
  "gender" INTEGER(1) DEFAULT 0,
  "country" TEXT(50),
  "province" TEXT(30),
  "city" TEXT(30),
  "address" TEXT(255),
  "telephone" TEXT(50),
  "im" TEXT(200),
  PRIMARY KEY ("member_id")
);

CREATE TABLE "@wa_member_group" (
  "member_gid" INTEGER(4) NOT NULL,
  "gname" TEXT(50) NOT NULL,
  "description" TEXT(255),
  "sys_perm" TEXT,
  "mem_perm" TEXT,
  "web_perm" TEXT,
  "sys_limit" TEXT,
  "mem_limit" TEXT,
  "web_limit" TEXT,
  PRIMARY KEY ("member_gid")
);

INSERT INTO "@wa_member_group" VALUES ('-1', 'Banned', 'No any permission.', '', '', '', '', '', '');
INSERT INTO "@wa_member_group" VALUES ('0', 'Guest', 'All front-end permissions.Maps all unregistered visitors.', '', '', '*.*', '', '', '');
INSERT INTO "@wa_member_group" VALUES ('1', 'Registered', 'All member area and front end permissions.', '', '*.*', '*.*', '', '', '');
INSERT INTO "@wa_member_group" VALUES ('999', 'Administrator', 'Part of admin area and full other permissions.', 'basic.access', '*.*', '*.*', '', '', '');
INSERT INTO "@wa_member_group" VALUES ('9999', 'Super Admin', 'All permissions over whole site,no any limit.', '*.*', '*.*', '*.*', '', '', '');

CREATE TABLE "@wa_member_setting" (
  "member_id" INTEGER(11) NOT NULL,
  "my_language" TEXT(30),
  "my_currency" TEXT(3),
  "my_timezone" TEXT(30),
  "my_locale" TEXT(20),
  PRIMARY KEY ("member_id")
);

CREATE TABLE "@wa_plugin" (
  "id" TEXT(50) NOT NULL,
  "type" TEXT(50) NOT NULL,
  "title" TEXT(50) NOT NULL,
  "version" TEXT(10),
  "creation_date" TEXT(30),
  "author" TEXT(100),
  "author_email" TEXT(150),
  "author_site" TEXT(200),
  "copyright" TEXT(255),
  "license" TEXT(255),
  "description" TEXT,
  PRIMARY KEY ("id")
);

CREATE INDEX "type" ON "@wa_plugin" ("type" ASC);

INSERT INTO "@wa_plugin" VALUES ('article', 'module', 'Article', '2.0', '2012-3-16', 'web@all', 'web@webatall.org', 'http://webatall.org', 'Copyright &copy; webatall.org', 'GNU LGPL', 'Article module');
INSERT INTO "@wa_plugin" VALUES ('member', 'module', 'Member', '2.0', '2012-3-16', 'web@all', 'web@webatall.org', 'http://webatall.org', 'Copyright &copy; webatall.org', 'GNU LGPL', 'Member module');
INSERT INTO "@wa_plugin" VALUES ('en', 'language', 'English', '2.0', '2012-3-16', 'web@all', 'web@webatall.org', 'http://webatall.org', 'Copyright &copy; webatall.org', 'GNU LGPL', 'Default language package.');
INSERT INTO "@wa_plugin" VALUES ('web', 'template', 'web', '2.0', '2012-3-16', 'web@all', 'web@webatall.org', 'http://webatall.org', 'Copyright &copy; webatall.org', 'GNU LGPL', 'Default template for front end');
INSERT INTO "@wa_plugin" VALUES ('paypal', 'payment', 'Paypal', '2.0', '2012-3-16', 'web@all', 'web@webatall.org', 'http://webatall.org', 'Copyright &copy; webatall.org', 'GNU LGPL', 'Paypal payment');
INSERT INTO "@wa_plugin" VALUES ('kindeditor', 'editor', 'KindEditor', '4.0.6', '2012-3-18', 'kindsoft', 'luolonghao@gmail.com', 'http://kindsoft.net', 'Copyright &copy; kindsoft.net.', 'http://www.kindsoft.net/license.php', 'KindEditor');

CREATE TABLE "@wa_transaction" (
  "trans_id" INTEGER AUTOINCREMENT NOT NULL,
  "trans_no" TEXT(50) NOT NULL,
  "type" INTEGER(1) DEFAULT 0,
  "status" INTEGER(1) DEFAULT 0,
  "amount" REAL NOT NULL,
  "unit" TEXT(3) NOT NULL,
  "text" TEXT(255),
  "member_id" INTEGER(11) DEFAULT 0,
  "username" TEXT(50),
  "timeadd" INTEGER(10) DEFAULT 0,
  "options" TEXT,
  PRIMARY KEY ("trans_id")
);

CREATE INDEX "trans_mid" ON "@wa_transaction" ("member_id" ASC);
CREATE INDEX "trans_no" ON "@wa_transaction" ("trans_no" ASC);

CREATE TABLE "@wa_unique" (
  "unique_id" INTEGER(15) NOT NULL,
  "unique_key" TEXT(50) NOT NULL,
  PRIMARY KEY ("unique_key")
);